# =====================================
# generator=datazen
# version=3.2.1
# hash=3f8116f823c41da22a8f89b4fffd9957
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A tool for working with scalable vector graphics."
PKG_NAME = "svgen"
VERSION = "0.7.12"
